HEADER

biouml.standard.type
Class Diagram type

Class Summary
BaseGeneral interface to be implemented by all classes to be used as BioUML diagram elements.
BaseSupportBase class for all data element types.
Biopolimer 
BiopolimerBeanInfoUtility class containing common metada for all molecules.
CellStub
CellBeanInfoUtility class containing common metada for all molecules.
CompartmentStub
CompartmentBeanInfo 
CompoundImported. Stub
DiagramDescriptionDefines coomon properties for diagram description.
EditionHistoryGeneral class defining editing history.
EnzymaticReactionStub
ExpressionStub
GeneStub
GeneBeanInfo 
GenericEntity 
GenericEntityBeanInfoUtility class containing common metada for all generic entities.
ImageDescriptor 
ImageDescriptorBeanInfo 
LiteratureReferenceDefines coomon properties of literature reference.
LiteratureReferenceBeanInfo 
MessageBundle 
Molecule 
MoleculeImported. Stub
MoleculeBeanInfoUtility class containing common metada for all molecules.
MoleculeBeanInfoImported.  
MultiLineHtmlFieldEditor 
ProteinStub
ProteinBeanInfo 
ProteinPropertiesDefines protein properties constants.
Reaction 
ReactionImported.  
ReactionBeanInfo 
ReactionBeanInfoImported.  
ReactionTypeStub
ReferrerExtention of GenericEntity that contains references to other databases and literature sources.
ReferrerBeanInfo 
RelationIntermediary class to generalize what is common for all relations/edges.
RelationBeanInfo 
RelationTypeThis interface is used to specify role of molecule involved in the reaction.
RNAStub
RNABeanInfo 
SpeciesGeneral definition for 'Species' concept.
SpeciesSpecificGeneral interface for species specific entities.
SubstanceStub
SubstanceBeanInfo 
TransportStub
TypeDefinition of data elemnt types (roles).
 


FOOTER

BOTTOM