| HEADER | |||||||
| PREV DIAGRAM NEXT DIAGRAM | FRAMES NO FRAMES | |||||||
| Class Summary | |
| Base | General interface to be implemented by all classes to be used as BioUML diagram elements. |
| BaseSupport | Base class for all data element types. |
| Biopolimer | |
| BiopolimerBeanInfo | Utility class containing common metada for all molecules. |
| Cell | Stub |
| CellBeanInfo | Utility class containing common metada for all molecules. |
| Compartment | Stub |
| CompartmentBeanInfo | |
| Compound | Imported. Stub |
| DiagramDescription | Defines coomon properties for diagram description. |
| EditionHistory | General class defining editing history. |
| EnzymaticReaction | Stub |
| Expression | Stub |
| Gene | Stub |
| GeneBeanInfo | |
| GenericEntity | |
| GenericEntityBeanInfo | Utility class containing common metada for all generic entities. |
| ImageDescriptor | |
| ImageDescriptorBeanInfo | |
| LiteratureReference | Defines coomon properties of literature reference. |
| LiteratureReferenceBeanInfo | |
| MessageBundle | |
| Molecule | |
| Molecule | Imported. Stub |
| MoleculeBeanInfo | Utility class containing common metada for all molecules. |
| MoleculeBeanInfo | Imported. |
| MultiLineHtmlFieldEditor | |
| Protein | Stub |
| ProteinBeanInfo | |
| ProteinProperties | Defines protein properties constants. |
| Reaction | |
| Reaction | Imported. |
| ReactionBeanInfo | |
| ReactionBeanInfo | Imported. |
| ReactionType | Stub |
| Referrer | Extention of GenericEntity that contains references to other databases and literature sources. |
| ReferrerBeanInfo | |
| Relation | Intermediary class to generalize what is common for all relations/edges. |
| RelationBeanInfo | |
| RelationType | This interface is used to specify role of molecule involved in the reaction. |
| RNA | Stub |
| RNABeanInfo | |
| Species | General definition for 'Species' concept. |
| SpeciesSpecific | General interface for species specific entities. |
| Substance | Stub |
| SubstanceBeanInfo | |
| Transport | Stub |
| Type | Definition of data elemnt types (roles). |
| FOOTER | |||||||
| PREV DIAGRAM NEXT DIAGRAM | FRAMES NO FRAMES | |||||||